Official UK Chicco website
Description: Our mission has always been to make a baby smile, helping mums and dads in their baby’s growth journey!

NEXT2ME

# Enjoy precious moments together with Next2me

The original side-sleeping crib
ENTER AND DISCOVER
DRY FIT

# The 2-in-1 nappy
for happy baby.

Maximum dryness and comfortable fit all in one nappy.
ENTER AND DISCOVER
Step Inside Santa's workshop to win this Christmas!

#

Guess which toys the Chicco elves are busy building and win them in time for Christmas!
ENTER HERE

# Who we are

Our mission has always been to make a baby smile, helping mums and dads in their baby’s growth journey. We provide safe solutions which are designed to meet the demands of babies as they progress through the growth phases, because for us happiness is a journey that starts when you’re a baby.

Toys
6m+ The Activity centre that evolves with your child to accompany their growth in total amusement!
123 Activity Walker- Orange
Sleeptime and Relaxation
AWARD WINNING
0M+ The innovative Chicco side-sleeping crib that promotes side sleeping and allows you to sleep close to your child, but not in the same bed.
Next2Me Side Sleeping Crib- Dove Grey
Mealtimes
5m+ Polly Magic is Chicco's multifunctional highchair which transforms for following the growth of your baby, from his first day at home up to 3 years: upon birth is a comfortable bouncer chair, at 6 months is a highchair, at 12 months a chair for hav...
Polly Magic Highchair
Toys
NEW in 2015
2 Years+ Available in 2015! Chicco introduce our newest member of the Turbo Team, Fiat 500 R/C!
Fiat 500 Remote Control Car
Toys
2 Years+ Electronic football goal!
Goal League
Toys
New Disney Princess
6M+ A magical dancing spinner. By pressing Cinderella's head down five marbles begin to spin around.
Disney Cinderella Dancing Spinner
Sleeptime and Relaxation
NEW
0M+ Ideal comfort for the first days, great fun for first discoveries.
Hoopla Rocker Chair
Urban Travel System

#### Your City Life has a new freedom!

Chicco Urban is the essence of transformability!

DISCOVER
Fit and Fun

#### Fit and Fun Range

A journey through sports and play that assists motor skills development.

READ MORE
First Dreams

#### A Magical Atmosphere for Sleep Time

Sleep time is a vital moment for all newborns. Studies on early childhood show that in order to help babies sleep peacefully, it is recommended to create a bedtime ritual in a relaxed and soothing environment.

READ MORE
Spare Parts

#### Spare Parts

We provide genuine Chicco spare parts for our most popular lines via our mini site.

SHOP
Happiness goes from heart to heart

#### SOCIAL COMMITMENT

Chicco has been supporting the Mission Bambini Foundation since 2013 with the "Happiness goes from heart to heart"project, raising funds to support medical interventions to treat children's heart diseases.

READ MORE
CHICCO WORLD

#### Chicco TV

Chicco's channel created to offer useful and simple video contents for helping you to live at best the most beautiful experience in the Worlds: being parents.

Enter and discover
osservatorio chicco

#### The expert answers

A team of experts who collaborate with the Osservatorio Chicco responds to the most frequently asked questions of parents.

Read the answers and ask a question
osservatorio chicco

#### Discover all about the Osservatorio Chicco

A facility dedicated to the knowledge of children from 0 to 3 years and its psycho-physical, emotional and social needs.

Enter
osservatorio chicco

#### The weaning

It has been amply demonstrated how eating habits formed in the first years of a child's life are maintained into adulthood.

Read more
Chicco UK
www.facebook.com/chiccocompanyuk